@@ -156,8 +156,8 @@ class Move(ModelSQL, ModelView):
 
     def search_rec_name(self, name, clause):
         ids = self.search(['OR',
-            ('reference',) + clause[1:],
-            (self._rec_name,) + clause[1:],
+            ('reference',) + tuple(clause[1:]),
+            (self._rec_name,) + tuple(clause[1:]),
             ])
         return [('id', 'in', ids)]
 
@@ -769,6 +769,8 @@ class Line(ModelSQL, ModelView):
         tax_code_obj = pool.get('account.tax.code')
         tax_obj = pool.get('account.tax')
         move_obj = pool.get('account.move')
+        tax_line_obj = pool.get('account.tax.line')
+
         if vals.get('move'):
             #Only for first line
             return res
@@ -803,14 +805,18 @@ class Line(ModelSQL, ModelView):
                 for code_id, tax_id in base_amounts:
                     if not base_amounts[code_id, tax_id]:
                         continue
-                    res.setdefault('add', []).append({
-                        'amount': base_amounts[code_id, tax_id],
-                        'currency_digits': account.currency_digits,
-                        'code': code_id,
-                        'code.rec_name': tax_code_obj.browse(code_id).rec_name,
-                        'tax': tax_id,
-                        'tax.rec_name': tax_obj.browse(tax_id).rec_name,
-                    })
+                    value = tax_line_obj.default_get(
+                        tax_line_obj._columns.keys())
+                    value.update({
+                            'amount': base_amounts[code_id, tax_id],
+                            'currency_digits': account.currency_digits,
+                            'code': code_id,
+                            'code.rec_name': tax_code_obj.browse(
+                                code_id).rec_name,
+                            'tax': tax_id,
+                            'tax.rec_name': tax_obj.browse(tax_id).rec_name,
+                            })
+                    res.setdefault('add', []).append(value)
         return res
 
     def on_change_party(self, vals):
@@ -880,7 +886,7 @@ class Line(ModelSQL, ModelView):
             else:
                 if 'account' not in res:
                     res['account'] = party.account_payable.id
-                    res['account.rec_name'] = party.account_payable.id
+                    res['account.rec_name'] = party.account_payable.rec_name
 
         if party and vals.get('credit'):
             if vals['credit'] > Decimal('0.0'):
@@ -1713,6 +1719,7 @@ class GeneralJournal(Report):
         clause = [
             ('date', '>=', datas['form']['from_date']),
             ('date', '<=', datas['form']['to_date']),
+            ('period.fiscalyear.company', '=', datas['form']['company']),
             ]
         if datas['form']['posted']:
             clause.append(('state', '=', 'posted'))
